@@ -7,6 +7,7 @@ import numpy as np
 
 from meggie.utilities.messaging import messagebox
 from meggie.utilities.messaging import exc_messagebox
+from meggie.utilities.plotting import set_figure_title
 
 from meggie.mainwindow.dynamic import Action
 from meggie.mainwindow.dynamic import subject_action
@@ -32,6 +33,6 @@ class PlotProjections(Action):
         fig = raw.plot_projs_topomap()
 
         elems = ['projections', subject.name]
-        fig.canvas.set_window_title('_'.join(elems))
+        set_figure_title(fig, '_'.join(elems))
         fig.suptitle(' '.join(elems))
 
