@@ -4,6 +4,12 @@
 import matplotlib
 matplotlib.use('Qt5Agg')
 
+# Use matplotlib as the backend for browser views for now,
+# as it is difficult to bind to qt close events and
+# because the functionality is still the same
+import mne
+mne.viz.set_browser_backend('matplotlib')
+
 from meggie import mainWindowMain
 
 
